@@ -7,7 +7,10 @@ class State:
     __slots__ = ('registers', 'data', 'pc')
 
     def __init__(self):
-        self.registers = array.array('B', map(lambda x:0, range(0, 7)))
+        self.registers = array.array('B', map(lambda x:0, range(0, 8)))
         self.data = array.array('B',
                 map(lambda x:0, range(0, 2**DATA_ADDRESS_WIDTH)))
         self.pc = 0
+
+    def freeze(self):
+        return (tuple(self.registers), tuple(self.data), self.pc)
